@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -138,11 +138,11 @@ DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
 DVBase[LA] = 4.44;
-DVBase[AA] = 0.144;
+DVBase[AA] = 0.2;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 1.77;
-DVBase[EPA] = 0.30;
-DVBase[DHA] = 0.35;
+DVBase[ALA] = 2.22;
+DVBase[EPA] = 0.3;
+DVBase[DHA] = 0.3;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -652,8 +652,11 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
+ fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+/*
  if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  else fprintf(fp,"\n");
+*/
  break;
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
@@ -764,8 +767,11 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);               
+fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
+/*
  if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  else fprintf(fp,"\n");
+*/
  break;
  }
 }
@@ -926,7 +932,7 @@ m->next = po;
 
 void compute_derived_fields(struct food *food_ptr)
 {
-float ratio;
+float ratio, realcal, alcCalFactor = 6.93;;
 food_ptr->nutrient[VITE] = 1.5 * food_ptr->nutrient[TOCPHA];
 food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2TT] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
 if (food_ptr->nutrient[LA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D2])) food_ptr->nutrient[LA] = NoData;
@@ -961,20 +967,21 @@ if (food_ptr->nutrient[OMEGA3] == 0 && test_for_negative_zero(&food_ptr->nutrien
 
 if ( food_ptr->prot_cal_factor == 0 && food_ptr->fat_cal_factor == 0 && food_ptr->cho_cal_factor == 0 && food_ptr->nutrient[ENERC_KCAL] > 0)
  {
- ratio = ((food_ptr->nutrient[PROCNT] * 4) + (food_ptr->nutrient[FAT] * 9) + (food_ptr->nutrient[CHOCDF] * 4)) / food_ptr->nutrient[ENERC_KCAL];
- if (ratio != 0)
-  {
-  food_ptr->nutrient[PROT_KCAL] = 4 * food_ptr->nutrient[PROCNT] / ratio;
-  food_ptr->nutrient[FAT_KCAL] = 9 * food_ptr->nutrient[FAT] / ratio;
-  food_ptr->nutrient[CHO_KCAL] = 4 * food_ptr->nutrient[CHOCDF] / ratio;
-  }
- } 
-else
- {
+ food_ptr->prot_cal_factor = 4;
+ food_ptr->fat_cal_factor = 9;
+ food_ptr->cho_cal_factor = 4;
  food_ptr->nutrient[PROT_KCAL] = food_ptr->prot_cal_factor * food_ptr->nutrient[PROCNT];
  food_ptr->nutrient[FAT_KCAL] = food_ptr->fat_cal_factor * food_ptr->nutrient[FAT];
  food_ptr->nutrient[CHO_KCAL] = food_ptr->cho_cal_factor * food_ptr->nutrient[CHOCDF];
+ realcal = food_ptr->nutrient[ENERC_KCAL] - (food_ptr->nutrient[ALC] * alcCalFactor);
+ ratio = realcal / (food_ptr->nutrient[PROT_KCAL] + food_ptr->nutrient[FAT_KCAL] + food_ptr->nutrient[CHO_KCAL]);
+ food_ptr->prot_cal_factor *= ratio;
+ food_ptr->fat_cal_factor *= ratio;
+ food_ptr->cho_cal_factor *= ratio;
  }
+food_ptr->nutrient[PROT_KCAL] = food_ptr->prot_cal_factor * food_ptr->nutrient[PROCNT];
+food_ptr->nutrient[FAT_KCAL] = food_ptr->fat_cal_factor * food_ptr->nutrient[FAT];
+food_ptr->nutrient[CHO_KCAL] = food_ptr->cho_cal_factor * food_ptr->nutrient[CHOCDF];
 food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
 if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
 }
