@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 
 struct opt options;
 
-static float DefaultTarget = 51, DefaultEPADHA = 6.4;
+static float DefaultTarget = 90, DefaultEPADHA = 0.6;
 
 void initialize_options()
 {
@@ -594,7 +594,8 @@ void efa_dynamics()
 {
 int i;
 float temp, temp1, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
-float target = DefaultTarget, epadhalimit, extra_ala;
+float kludgefactor = .9;
+float target = DefaultTarget + kludgefactor, epadhalimit, extra_ala;
 
 if (options.n6hufa != 0)
  {
@@ -602,59 +603,44 @@ if (options.n6hufa != 0)
  if (options.n6hufa > 90) options.n6hufa = 90;
  }
   
-/*
-DV[ALA] = food_work.nutrient[ALA];
-if (DV[ALA] <= 0) DV[ALA] = .00001;
-*/
-  
+if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
+else epadhalimit = options.epadhamax;
 
-if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
-  
+options.abnuts[ALA] = food_work.nutrient[ALA];
+if (options.abnuts[ALA] <= 0) options.abnuts[ALA] = .00001;
 
-if (options.n6hufa == 90 || options.n6hufa == 15)
+if ( (DefaultTarget == 90 && options.n6hufa == 0) || options.n6hufa == 90 || options.n6hufa == 15)
  {
- DV[OMEGA6] = food_work.nutrient[OMEGA6];
- if (DV[OMEGA6] <= 0) DV[OMEGA6] = .00001;
- options.abnuts[OMEGA6] = DV[OMEGA6];
- DV[LA] = food_work.nutrient[LA];
- if (DV[LA] <= 0) DV[LA] = .00001;
- options.abnuts[LA] = DV[LA];
- DV[AA] = food_work.nutrient[AA];
- if (DV[AA] <= 0) DV[AA] = .00001;
- options.abnuts[AA] = DV[AA];
- DV[OMEGA3] = food_work.nutrient[OMEGA3];
- if (DV[OMEGA3] <= 0) DV[OMEGA3] = .00001;
- options.abnuts[OMEGA3] = DV[OMEGA3];
- DV[ALA] = food_work.nutrient[ALA];
- if (DV[ALA] <= 0) DV[ALA] = .00001;
- options.abnuts[ALA] = DV[ALA];
- DV[EPA] = food_work.nutrient[EPA];
- if (DV[EPA] <= 0) DV[EPA] = .00001;
- options.abnuts[EPA] = DV[EPA];
- DV[DHA] = food_work.nutrient[DHA];
- if (DV[DHA] <= 0) DV[DHA] = .00001;
- options.abnuts[DHA] = DV[DHA];
-/*
- if (options.epadhamax < options.abnuts[EPA] + options.abnuts[DHA])
+ options.abnuts[OMEGA6] = food_work.nutrient[OMEGA6];
+ if (options.abnuts[OMEGA6] <= 0) options.abnuts[OMEGA6] = .00001;
+ options.abnuts[LA] = food_work.nutrient[LA];
+ if (options.abnuts[LA] <= 0) options.abnuts[LA] = .00001;
+ options.abnuts[AA] = food_work.nutrient[AA];
+ if (options.abnuts[AA] <= 0) options.abnuts[AA] = .00001;
+ options.abnuts[OMEGA3] = food_work.nutrient[OMEGA3];
+ if (options.abnuts[OMEGA3] <= 0) options.abnuts[OMEGA3] = .00001;
+ options.abnuts[ALA] = food_work.nutrient[ALA];
+ if (options.abnuts[ALA] <= 0) options.abnuts[ALA] = .00001;
+ options.abnuts[EPA] = food_work.nutrient[EPA];
+ if (options.abnuts[EPA] <= 0) options.abnuts[EPA] = .00001;
+ options.abnuts[DHA] = food_work.nutrient[DHA];
+ if (options.abnuts[DHA] <= 0) options.abnuts[DHA] = .00001;
+ if (options.abnuts[EPA] + options.abnuts[DHA] < DefaultEPADHA && (food_work.nutrient[EPA] > .01 || food_work.nutrient[DHA] > .01 || food_work.nutrient[AA] > .01))
   {
-  temp = options.abnuts[EPA] + options.abnuts[DHA] - options.epadhamax;
-  temp1 = options.abnuts[EPA] / (options.abnuts[EPA] + options.abnuts[DHA]);
-  DV[EPA] = options.abnuts[EPA] -= temp * temp1;
-  DV[DHA] = options.abnuts[DHA] -= temp * (1 - temp1);
-  DV[OMEGA3] = options.abnuts[OMEGA3] -= temp;
+  temp1 = epadhalimit - (options.abnuts[EPA] + options.abnuts[DHA]);
+  temp = epadhalimit / (options.abnuts[EPA] + options.abnuts[DHA]);
+  options.abnuts[EPA] *= temp;
+  options.abnuts[DHA] *= temp;
+  options.abnuts[OMEGA3] += temp1;
   }
-*/
  return;
  }
 
-if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
-else epadhalimit = options.epadhamax;
-if (options.n6hufa != 0) target = options.n6hufa;
+if (options.n6hufa != 0) target = options.n6hufa + kludgefactor;
 
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
-options.abnuts[ALA] = DV[ALA];
-extra_ala = DV[ALA] - food_work.nutrient[ALA];
+extra_ala = options.abnuts[ALA] - food_work.nutrient[ALA];
 p3 = 902 * (food_work.nutrient[SHORT3] + extra_ala) / food_work.nutrient[ENERC_KCAL];
 p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
 h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
